/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.business.beans.application;

import java.util.Collections;
import java.util.Map;

import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

/**
 * The {@link ThemeSwitcherBean} is responsible for holding a list with all application wide available themes (look and feels). As this is a static list, it is not
 * possible to import new themes during the runtime. The initialization is done in the Spring configuration file.<br>
 * This class is a singleton scoped Spring managed bean, as the list with the available themes is a static list.
 * 
 * @author Nils Christian Ehmke
 */
@Component
@Scope("singleton")
public final class ThemeSwitcherBean {

	private Map<String, String> themes;

	/**
	 * Default constructor. <b>Do not use this constructor. This bean is Spring managed.</b>
	 */
	public ThemeSwitcherBean() {
		// No code necessary
	}

	/**
	 * Returns the available themes.
	 * 
	 * @return A map containing the user readable names of the themes as a key and the actual theme-names as the corresponding value. The map can not be modified.
	 */
	public Map<String, String> getThemes() {
		return Collections.unmodifiableMap(this.themes);
	}

	/**
	 * The setter for the property {@link ThemeSwitcherBean#themes}. <b>Do not use this method. This property is Spring managed.</b>
	 * 
	 * @param themes
	 *            The value for the property.
	 */
	public void setThemes(final Map<String, String> themes) {
		this.themes = themes;
	}
}
