/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.business.beans.view;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import kieker.webgui.business.beans.application.ProjectsBean;

import org.primefaces.event.SelectEvent;

/**
 * The {@link CurrentProjectOverviewBean} contains the necessary data behind an instance of the project overview.<br>
 * The class is a Spring managed bean with view scope.
 * 
 * @author Nils Christian Ehmke
 */
@Component
@Scope("view")
public final class CurrentProjectOverviewBean implements InitializingBean {

	@Autowired
	private ProjectsBean projectsBean;
	/**
	 * This list contains all available projects by name.
	 */
	private List<String> projects = new ArrayList<String>();
	/**
	 * The name of the "selected" project.
	 */
	private String projectName;

	/**
	 * Default constructor. <b>Do not call this constructor manually. It will only be accessed by Spring.</b>
	 */
	public CurrentProjectOverviewBean() {
		// No code necessary
	}

	/**
	 * Delivers the currently "selected" project name.
	 * 
	 * @return The name of the project.
	 */
	public String getProjectName() {
		return this.projectName;
	}

	/**
	 * Sets the currently "selected" project name.
	 * 
	 * @param projectName
	 *            The name of the project.
	 */
	public void setProjectName(final String projectName) {
		this.projectName = projectName;
	}

	/**
	 * This is the event listener used to select a row instantaneously.
	 * 
	 * @param event
	 *            The select event.
	 */
	public void onRowSelect(final SelectEvent event) {
		this.setProjectName((String) event.getObject());
	}

	/**
	 * Setter for the property {@link CurrentProjectOverviewBean#projectsBean}.
	 * 
	 * @param projectsBean
	 *            The new value for the property.
	 */
	public void setProjectsBean(final ProjectsBean projectsBean) {
		this.projectsBean = projectsBean;
	}

	/**
	 * Updates the list containing the available projects name.
	 */
	public void updateLists() {
		this.projects = this.projectsBean.getProjects();
	}

	/**
	 * This method delivers all available projects as a list of string.
	 * 
	 * @return All currently available projects.
	 */
	public List<String> getProjects() {
		return this.projects;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.springframework.beans.factory.InitializingBean#afterPropertiesSet()
	 */
	@Override
	public void afterPropertiesSet() throws Exception {
		this.updateLists();
	}

}
