/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.persistence;

import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Collection;
import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;

import kieker.analysis.model.analysisMetaModel.MIDependency;
import kieker.webgui.common.ClassAndMethodContainer;
import kieker.webgui.common.exception.LibraryAlreadyExistingException;
import kieker.webgui.common.exception.NewerProjectException;
import kieker.webgui.common.exception.ProjectAlreadyExistingException;
import kieker.webgui.common.exception.ProjectNotExistingException;
import kieker.webgui.domain.Project;

import org.primefaces.model.UploadedFile;

/**
 * This is the interface for the project data access object. The implementing class will be responsible for managing projects in a transactional way. This interface
 * will only be accessible by authenticated users.
 * 
 * @author Nils Christian Ehmke
 */
public interface IProjectDAO {

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public void addProject(final Project project) throws IOException, ProjectAlreadyExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public void saveProject(final Project project, final long timeStamp, final boolean overwriteNewerProject) throws ProjectNotExistingException, IOException,
			NewerProjectException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public void copyProject(final String srcProjectName, final String dstProjectName) throws IOException, ProjectNotExistingException,
			ProjectAlreadyExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public Project openProject(final String projectName) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public Object openProject(final String projectName, final ClassAndMethodContainer classAndMethodContainer) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public long getCurrTimestamp(final String projectName) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public void uploadLibrary(final UploadedFile file, final Project project) throws IOException, ProjectNotExistingException, LibraryAlreadyExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public ClassLoader getClassLoader(final Project project) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public Collection<String> listAllProjects();

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public File getProjectFile(final String projectName);

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public URL getKiekerURL();

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public URL getURL(final MIDependency lib, final Project project) throws MalformedURLException;

	@PreAuthorize("isAuthenticated()")
	@Transactional
	public List<String> listAllLibraries(final Project project) throws ProjectNotExistingException;

}
