/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.persistence;

import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;

import kieker.webgui.common.exception.DataAccessException;
import kieker.webgui.domain.User;

/**
 * This is the interface for the user data access object. The implementing class will be responsible for managing user in a transactional way. This interface will
 * only be accessible by administrators.
 * 
 * @author Nils Christian Ehmke
 */
public interface IUserDAO {

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	@Transactional()
	public void addUser(final User user) throws DataAccessException;

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	@Transactional
	public void editUserWithoutPassword(final User user) throws DataAccessException;

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	@Transactional
	public void editUserWithPassword(final User user) throws DataAccessException;

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	@Transactional
	public void deleteUser(final User user) throws DataAccessException;

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	@Transactional(readOnly = true)
	public List<User> getUsers();

}
