/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.service;

import java.io.IOException;
import java.util.Collection;
import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;

import kieker.analysis.AnalysisController.STATE;
import kieker.analysis.model.analysisMetaModel.MIDependency;
import kieker.analysis.plugin.AbstractPlugin;
import kieker.analysis.repository.AbstractRepository;
import kieker.webgui.common.ClassAndMethodContainer;
import kieker.webgui.common.exception.AnalysisInitializationException;
import kieker.webgui.common.exception.AnalysisStateException;
import kieker.webgui.common.exception.DisplayNotFoundException;
import kieker.webgui.common.exception.LibraryAlreadyExistingException;
import kieker.webgui.common.exception.LibraryLoadException;
import kieker.webgui.common.exception.NewerProjectException;
import kieker.webgui.common.exception.ProjectAlreadyExistingException;
import kieker.webgui.common.exception.ProjectNotExistingException;
import kieker.webgui.domain.Project;

import org.primefaces.model.UploadedFile;

/**
 * This is the interface for the project service, which is responsible for managing the available projects. This interface will only be accessible by authenticated
 * users.
 * 
 * @author Nils Christian Ehmke
 */
public interface IProjectService {

	@PreAuthorize("isAuthenticated()")
	public void addProject(final Project project) throws IOException, ProjectAlreadyExistingException;

	@PreAuthorize("isAuthenticated()")
	public void editProject(final Project project) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public void editProject(final Project project, final long timestamp) throws IOException, ProjectNotExistingException, NewerProjectException;

	@PreAuthorize("isAuthenticated()")
	public void copyProject(final String srcProjectName, final String dstProjectName) throws IOException, ProjectNotExistingException,
			ProjectAlreadyExistingException;

	@PreAuthorize("isAuthenticated()")
	public Project openProject(final String projectName) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public Object openProject(final String projectName, final ClassAndMethodContainer classAndMethodContainer) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public long getCurrTimestamp(final String projectName) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public void uploadLibrary(final UploadedFile file, final Project project) throws IOException, ProjectNotExistingException, LibraryAlreadyExistingException;

	@PreAuthorize("isAuthenticated()")
	public ClassLoader getClassLoader(final Project project) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public ClassLoader getClassLoader(final String projectName) throws IOException, ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public List<Class<AbstractRepository>> getAllRepositoriesWithinLib(final MIDependency lib, final Project project, final ClassLoader classLoader,
			final ClassAndMethodContainer classAndMethodContainer) throws LibraryLoadException;

	@PreAuthorize("isAuthenticated()")
	public List<Class<AbstractPlugin>> getAllPluginsWithinLib(final MIDependency lib, final Project project, final ClassLoader classLoader,
			final ClassAndMethodContainer classAndMethodContainer) throws LibraryLoadException;

	@PreAuthorize("isAuthenticated()")
	public List<Class<AbstractRepository>> getAllRepositoriesWithinKiekerLib(final ClassLoader classLoader, final ClassAndMethodContainer classAndMethodContainer)
			throws LibraryLoadException;

	@PreAuthorize("isAuthenticated()")
	public List<Class<AbstractPlugin>> getAllPluginsWithinKiekerLib(final ClassLoader classLoader, final ClassAndMethodContainer classAndMethodContainer)
			throws LibraryLoadException;

	@PreAuthorize("isAuthenticated()")
	public Collection<String> listAllProjects();

	@PreAuthorize("isAuthenticated()")
	public void initializeAnalysis(final String projectName, final ClassLoader classLoader) throws ProjectNotExistingException, AnalysisStateException,
			AnalysisInitializationException;

	@PreAuthorize("isAuthenticated()")
	public void cleanAnalysis(final String projectName) throws ProjectNotExistingException, AnalysisStateException;

	@PreAuthorize("isAuthenticated()")
	public void startAnalysis(final String projectName) throws ProjectNotExistingException, AnalysisStateException;

	@PreAuthorize("isAuthenticated()")
	public void stopAnalysis(final String projectName) throws ProjectNotExistingException, AnalysisStateException;

	@PreAuthorize("isAuthenticated()")
	public Object getDisplay(final String projectName, final String viewName, final String displayName) throws ProjectNotExistingException, DisplayNotFoundException;

	@PreAuthorize("isAuthenticated()")
	public STATE getCurrentState(final String projectName) throws ProjectNotExistingException;

	@PreAuthorize("isAuthenticated()")
	public Object[] getLogEntries(final String projectName) throws AnalysisStateException;

	@PreAuthorize("isAuthenticated()")
	public List<String> listAllLibraries(final Project project) throws ProjectNotExistingException;
}
