/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.service;

import java.util.List;

import org.springframework.security.access.prepost.PreAuthorize;

import kieker.webgui.common.exception.DataAccessException;
import kieker.webgui.domain.User;

/**
 * This is the interface for the user service, responsible for managing the available users within the system. This interface will only be accessible by
 * administrators.
 * 
 * @author Nils Christian Ehmke
 */
public interface IUserService {

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void addUser(final User user);

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void editUserWithoutPassword(final User user) throws DataAccessException;

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void editUserWithPassword(final User user) throws DataAccessException;

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void deleteUser(final User user);

	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public List<User> getUsers();

}
