/***************************************************************************
 * Copyright 2012 Kieker Project (http://kieker-monitoring.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Service;

import kieker.webgui.common.exception.DataAccessException;
import kieker.webgui.domain.User;
import kieker.webgui.persistence.IUserDAO;
import kieker.webgui.service.IUserService;

@Service
@Scope("singleton")
public class UserServiceImpl implements IUserService {

	@Autowired
	private IUserDAO userDAO;

	public UserServiceImpl() {
		// No code necessary
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see kieker.webgui.service.IUserService#addUser(kieker.webgui.domain.User)
	 */
	@Override
	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void addUser(final User user) {
		this.userDAO.addUser(user);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see kieker.webgui.service.IUserService#editUserWithoutPassword(kieker.webgui.domain.User)
	 */
	@Override
	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void editUserWithoutPassword(final User user) throws DataAccessException {
		this.userDAO.editUserWithoutPassword(user);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see kieker.webgui.service.IUserService#editUserWithPassword(kieker.webgui.domain.User)
	 */
	@Override
	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void editUserWithPassword(final User user) throws DataAccessException {
		this.userDAO.editUserWithPassword(user);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see kieker.webgui.service.IUserService#deleteUser(kieker.webgui.domain.User)
	 */
	@Override
	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public void deleteUser(final User user) {
		this.userDAO.deleteUser(user);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see kieker.webgui.service.IUserService#getUsers()
	 */
	@Override
	@PreAuthorize("hasRole('ROLE_ADMIN')")
	public List<User> getUsers() {
		return this.userDAO.getUsers();
	}

}
